@@ -10,6 +10,8 @@
 
 
 import logging
+import warnings
+import sys
 
 from .core import SoCo
 from .discovery import discover, discover_thread
@@ -19,7 +21,7 @@ from .exceptions import SoCoException, UnknownSoCoException
 __author__ = 'Anders Melchiorsen <amelchio@nogoto.net>'
 # Please add the suffix "+" to the version after release, to make it
 # possible infer whether in development code from the version string
-__version__ = '0.0.26'
+__version__ = '0.0.27'
 __website__ = 'https://github.com/amelchio/pysonos'
 __license__ = 'MIT License'
 
@@ -37,3 +39,9 @@ __all__ = [
 # Avoids spurious error messages if no logger is configured by the user
 
 logging.getLogger(__name__).addHandler(logging.NullHandler())
+
+if sys.version_info.major < 3:
+    warnings.warn(
+        "Version 0.19 of SoCo is the last to support Python 2.7",
+        stacklevel=2,
+    )
